@@ -10,11 +10,8 @@ class EncoderDecoder(base.Model):
     # CONSTANTS
     #
     NAME='EncoderDecoder'
-
-
     def __init__(self,
             nb_classes=None,
-            output_size=None,
             model_config=NAME,
             key_path=NAME,
             is_file_path=False,
@@ -27,17 +24,25 @@ class EncoderDecoder(base.Model):
             decoder_key_path=None,
             decoder_is_file_path=None,
             decoder_cfig_dir=None,
-            classifier_position=Decoder.AFTER_UP,
             classifier_config={
                 'classifier_type': base.Model.SEGMENT,
             },
+            classifier_key_path=None,
+            classifier_is_file_path=False,
+            classifier_cfig_dir=load.TFBOX,
             name=NAME,
             named_layers=True,
             noisy=True):
         super(EncoderDecoder, self).__init__(
             name=name,
             named_layers=named_layers,
+            nb_classes=nb_classes,
+            classifier_config=classifier_config,
+            classifier_key_path=classifier_key_path,
+            classifier_is_file_path=classifier_is_file_path,
+            classifier_cfig_dir=classifier_cfig_dir,
             noisy=noisy)
+
         if isinstance(model_config,str):
             model_config=load.config(
                     cfig=model_config,
@@ -60,23 +65,28 @@ class EncoderDecoder(base.Model):
                     is_file_path=self._value(decoder_is_file_path,is_file_path),
                     cfig_dir=self._value(decoder_cfig_dir,cfig_dir),
                     noisy=noisy )
-        decoder_config['classifier_config']=self._value(
-                decoder_config.get('classifier_config'),
-                classifier_config )
-        decoder_config['classifier_position']=self._value(
-            decoder_config.get('classifier_position'),
-            classifier_position )
-        decoder_config['output_size']=self._value(
-            output_size,
-            decoder_config.get('output_size'))
-        self.encoder=Encoder(model_config=encoder_config,return_empty_skips=True)
-        self.decoder=Decoder(nb_classes=nb_classes,model_config=decoder_config)
+        # encoder 
+        self.encoder=Encoder(
+            nb_classes=None,
+            model_config=encoder_config,
+            return_empty_skips=True)
+        # decoder
+        oc=decoder_config.get('output_conv')
+        if isinstance(oc,dict):
+            oc['filters']=oc.get('filters',nb_classes)
+        elif oc is None:
+            oc=nb_classes
+        decoder_config['output_conv']=oc
+        self.decoder=Decoder(
+            nb_classes=None,
+            model_config=decoder_config)
 
 
     def __call__(self,inputs,training=False):
         x,skips=self.encoder(inputs)
         self.decoder.set_output(inputs)
-        return self.decoder(x,skips,training)
+        x=self.decoder(x,skips,training)
+        return self.output(x)
 
 
     #
